==> haskell-asn1-encoding-0.9.5-14-i686.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.5
id: asn1-encoding-0.9.5-G2vSb6H0NGaDVov1mRysau
key: asn1-encoding-0.9.5-G2vSb6H0NGaDVov1mRysau
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.ASN1.BinaryEncoding Data.ASN1.BinaryEncoding.Raw
    Data.ASN1.Encoding Data.ASN1.Error Data.ASN1.Object
    Data.ASN1.Stream
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
abi: 4b10735e9d1cd3644178b622b90dff2a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/asn1-encoding-0.9.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/asn1-encoding-0.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/asn1-encoding-0.9.5
hs-libraries: HSasn1-encoding-0.9.5-G2vSb6H0NGaDVov1mRysau
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    hourglass-0.2.10-6vUY2VFiM1E873akQp7ZFT
    asn1-types-0.3.2-61vI6GmIqV4BnqsxINTnsF
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             hourglass-0.2.10-6vUY2VFiM1E873akQp7ZFT=a7b4dc3a31dc3314e8c5a212498714d7
             asn1-types-0.3.2-61vI6GmIqV4BnqsxINTnsF=67326da5b916cbf377ae50e7c9a8e9a5
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-encoding-0.9.5-17-i686.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.5
id: asn1-encoding-0.9.5-IbtBEvbsKOBAFXA8bzYUf0
key: asn1-encoding-0.9.5-IbtBEvbsKOBAFXA8bzYUf0
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.ASN1.BinaryEncoding Data.ASN1.BinaryEncoding.Raw
    Data.ASN1.Encoding Data.ASN1.Error Data.ASN1.Object
    Data.ASN1.Stream
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
abi: c3cc95f30ea84cd7e1e5137c7383bf44
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/asn1-encoding-0.9.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/asn1-encoding-0.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/asn1-encoding-0.9.5
hs-libraries: HSasn1-encoding-0.9.5-IbtBEvbsKOBAFXA8bzYUf0
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    hourglass-0.2.10-6vUY2VFiM1E873akQp7ZFT
    asn1-types-0.3.2-EtZT2ZJVgtsHoacxlkz9v7
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             hourglass-0.2.10-6vUY2VFiM1E873akQp7ZFT=a7b4dc3a31dc3314e8c5a212498714d7
             asn1-types-0.3.2-EtZT2ZJVgtsHoacxlkz9v7=f2137186d677937bbd84fceb048c4622
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
